@@ -1,6 +1,6 @@
 # PMML: Predictive Model Markup Language
 #
-# Copyright (c) 2009-2013, some parts by Togaware Pty Ltd and other by Zementis, Inc. 
+# Copyright (c) 2009-2017, some parts by Togaware Pty Ltd and other by Zementis, Inc. 
 #
 # This file is part of the PMML package for R.
 #
@@ -16,8 +16,6 @@
 ######################################################################################
 #
 # Author: Wen Lin
-# Date: Sep 2013
-#------------------------------------------------------------------------------------
 
 pmml.ada <- function(model,
                        model.name="AdaBoost_Model",
@@ -47,7 +45,7 @@ pmml.ada <- function(model,
    #----------------------------------------------------------
    # PMML
   
-   pmml <- .pmmlRootNode("4.2")
+   pmml <- .pmmlRootNode()
   
    #----------------------------------------------------------
    # PMML -> Header
